==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-lineChart.dart <==
/*
Implementation:

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'custom-lineChart.dart';
charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.


    Object:
      static List<LinearSales> objLineOne = [
          new LinearSales(0, 5),
          new LinearSales(20, 25),
          new LinearSales(30, 50),
          new LinearSales(40, 60),
        ];

        static List<LinearSales> objLineTwo = [
          new LinearSales(0, 15),
          new LinearSales(20, 35),
          new LinearSales(30, 60),
          new LinearSales(40, 80),
        ];

        static List<LinearSales> objLineThree = [
          new LinearSales(0, 16),
          new LinearSales(20, 36),
          new LinearSales(30, 10),
          new LinearSales(40, 20),
        ];


        new charts.Series<LinearSales, int>(
        id: 'SomeId',
        colorFn: (_, __) => charts.MaterialPalette.pink.shadeDefault,
        domainFn: (LinearSales sales, _) => sales.year,
        measureFn: (LinearSales sales, _) => sales.sales,
        data: objLineOne,
      ),
      new charts.Series<LinearSales, int>(
        id: 'SomeId',
        colorFn: (_, __) => charts.MaterialPalette.blue.shadeDefault,
        domainFn: (LinearSales sales, _) => sales.year,
        measureFn: (LinearSales sales, _) => sales.sales,
        data: objLineTwo,
      ),
      new charts.Series<LinearSales, int>(
        id: 'SomeId',
        colorFn: (_, __) => charts.MaterialPalette.deepOrange.shadeDefault,
        domainFn: (LinearSales sales, _) => sales.year,
        measureFn: (LinearSales sales, _) => sales.sales,
        data: objLineThree,
      )
    ];
    ChartsLine objLineChart = new ChartsLine(objSeries);

    Object Call:
        body: objLineChart
*/


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'consts.dart' as con;


class ChartsLine extends StatefulWidget{
 final List<charts.Series<dynamic,dynamic>> chartData;

  ChartsLine(this.chartData);

  @override
  State<StatefulWidget> createState() {
    return _Chartsline(chartData);
  }
}

class _Chartsline extends State<ChartsLine>{
  List<charts.Series<dynamic,dynamic>> chartData;

  _Chartsline(this.chartData);


  @override
  Widget build(BuildContext context) {
    return _createLineChart(chartData);
  }

  Widget _createLineChart(List<charts.Series<dynamic,dynamic>> objSeries)
  {
    charts.LineChart mLineChart;
    mLineChart = charts.LineChart(
        objSeries,
        animationDuration: Duration(seconds: con.five),
        animate: true,
        defaultRenderer: new charts.LineRendererConfig(
            includeArea: true, stacked: false, includePoints: true
        )
    );
    return mLineChart;
  }
}

==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-lineChart.dart <==
/*
Implementation:

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'custom-lineChart.dart';
charts_flutter: ^0.9.0 dependency is added to pubspec.yaml file.


    Object:
      static List<LinearSales> objLineOne = [
          new LinearSales(0, 5),
          new LinearSales(20, 25),
          new LinearSales(30, 50),
          new LinearSales(40, 60),
        ];

        static List<LinearSales> objLineTwo = [
          new LinearSales(0, 15),
          new LinearSales(20, 35),
          new LinearSales(30, 60),
          new LinearSales(40, 80),
        ];

        static List<LinearSales> objLineThree = [
          new LinearSales(0, 16),
          new LinearSales(20, 36),
          new LinearSales(30, 10),
          new LinearSales(40, 20),
        ];


        new charts.Series<LinearSales, int>(
        id: 'SomeId',
        colorFn: (_, __) => charts.MaterialPalette.pink.shadeDefault,
        domainFn: (LinearSales sales, _) => sales.year,
        measureFn: (LinearSales sales, _) => sales.sales,
        data: objLineOne,
      ),
      new charts.Series<LinearSales, int>(
        id: 'SomeId',
        colorFn: (_, __) => charts.MaterialPalette.blue.shadeDefault,
        domainFn: (LinearSales sales, _) => sales.year,
        measureFn: (LinearSales sales, _) => sales.sales,
        data: objLineTwo,
      ),
      new charts.Series<LinearSales, int>(
        id: 'SomeId',
        colorFn: (_, __) => charts.MaterialPalette.deepOrange.shadeDefault,
        domainFn: (LinearSales sales, _) => sales.year,
        measureFn: (LinearSales sales, _) => sales.sales,
        data: objLineThree,
      )
    ];
    ChartsLine objLineChart = new ChartsLine(objSeries);

    Object Call:
        body: objLineChart
*/


import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:charts_flutter/flutter.dart' as charts;
import 'package:flutter_catalogue_widgets/consts.dart' as con;


class ChartsLine extends StatefulWidget{
 final List<charts.Series<dynamic,dynamic>> chartData;

  ChartsLine(this.chartData);

  @override
  State<StatefulWidget> createState() {
    return _Chartsline(chartData);
  }
}

class _Chartsline extends State<ChartsLine>{
  List<charts.Series<dynamic,dynamic>> chartData;

  _Chartsline(this.chartData);


  @override
  Widget build(BuildContext context) {
    return _createLineChart(chartData);
  }

  Widget _createLineChart(List<charts.Series<dynamic,dynamic>> objSeries)
  {
    charts.LineChart mLineChart;
    mLineChart = charts.LineChart(
        objSeries,
        animationDuration: Duration(seconds: con.five),
        animate: true,
        defaultRenderer: new charts.LineRendererConfig(
            includeArea: true, stacked: false, includePoints: true
        )
    );
    return mLineChart;
  }
}
